# PythonODFTemplator
## ODF templating library for python.
PythonODFTemplator is a template library for embedding values in [LibreOffice](https://www.libreoffice.org/) documents(ODF).
[Jinja2](https://palletsprojects.com/p/jinja/) is used for the syntax to embed values in documents.
The result of embedding the values can be output as a LibreOffice document(ODF) or PDF.

This library was written by [Kenji Nishishiro](mailto:marvel@programmershigh.org).
## Build instructions
```
pip install PythonODFTemplator
```
## How to use PythonODFTemplator
Please read the source.

## Licence
MIT License
